@@ -23,7 +23,7 @@ class Fond(QGraphicsView):
         self.myCurrentPoint = QPoint(0,0)
         self.myFirstScale  = 1.0
         self.myOrig = QPointF(400, 200)
-        self.moved = False
+        self.zooming = False
         self.dblClicked = False
 
         self.animSeq = QSequentialAnimationGroup()
@@ -40,33 +40,32 @@ class Fond(QGraphicsView):
 
     def mousePressEvent(self,event):
         self.emit(SIGNAL("pressed()"))
+        self.myFirstPoint = event.pos()
         QGraphicsView.mousePressEvent (self, event)
-        
+
     def mouseDoubleClickEvent(self, event):
         self.dblClicked = True
-        self.myFirstPoint = event.pos()
-        self.myCurrentPoint = event.pos()
-        QObject.connect(self, SIGNAL("position(QPointF)"), self.zoom)
         QGraphicsView.mouseDoubleClickEvent (self, event)
 
 
     def mouseReleaseEvent(self,event):
-        self.emit(SIGNAL("released()"))
         QObject.disconnect(self, SIGNAL("position(QPointF)"), self.zoom)
-        if QRect( self.myFirstPoint-QPoint(5,5) , self.myFirstPoint+QPoint(5,5)).contains(self.myCurrentPoint)  and self.dblClicked:
-            self.dblClicked = False
+        if not self.zooming and self.dblClicked:
             self.scene().doubleClick(self.mapToScene(event.pos()))
-        else:
-            self.dblClicked = False
-            self.moved = False
-        QGraphicsView.mouseReleaseEvent (self, event)
-            
+        self.zooming = False
+        self.dblClicked = False
+        QGraphicsView.mouseReleaseEvent (self, event)        
 
     def mouseMoveEvent(self,event):
-        self.moved = True
+        if not self.zooming:
+            if not QRect( self.myFirstPoint-QPoint(10,10) , self.myFirstPoint+QPoint(10,10)).contains(event.pos()):
+                if self.dblClicked:
+                    self.zooming = True
+                    QObject.connect(self, SIGNAL("position(QPointF)"), self.zoom)
+                QGraphicsView.mouseMoveEvent (self, event)
+        else:
+            QGraphicsView.mouseMoveEvent (self, event)
         self.emit(SIGNAL("position(QPointF)"),event.posF())
-        self.myCurrentPoint = event.pos()
-        QGraphicsView.mouseMoveEvent (self, event)
 
 ###Actions
 
@@ -83,12 +82,12 @@ class Fond(QGraphicsView):
         scale = self.dist(point,centre) / self.dist(self.myFirstPoint,centre) 
         self.multScale(scale)
 
+
     def multScale(self,scale):
-        self.Scale = max(min(self.Scale * scale**.5, 5.),.21)
-        if self.Scale != 5. and self.Scale != .21:
+        self.Scale = max(min(self.Scale * scale**.5, 6.),.2)
+        if self.Scale != 6. and self.Scale != .2:
             self.scale( scale**.5, scale**.5)
 #            self.emit(SIGNAL("zoom(float)"),scale**.5)
-            self.update()
             
     def getScale(self):
         return self.Scale
@@ -147,6 +146,8 @@ class Carte(QGraphicsScene):
         blurred = False
 
 
+
+
       
       
 #Panneau Station  
@@ -288,9 +289,10 @@ class GpsButton(QLabel):
         self.setScaledContents( True )
         self.setMargin(16)
         self.state = False
+        self.fixed = False
 
         self.animMargin = QPropertyAnimation (self, "margin")
-        self.animMargin.setDuration(_TEMPS_ANIM)
+        self.animMargin.setDuration(_TEMPS_ANIM*1.5)
         self.animMargin.setEasingCurve(QEasingCurve.OutElastic)
         self.animMargin.setKeyValueAt(0, 8)
         self.animMargin.setKeyValueAt(1, 16)
@@ -342,12 +344,23 @@ class GpsButton(QLabel):
             self.setPix('Off')
 #            QObject.disconnect(self.click, SIGNAL("timeout()"), self.center)
             self.state = False
+            self.fixed = False
 
-        else:
-            self.emit(SIGNAL("gpsOn"))
+        elif self.fixed:
+            self.animMargin.stop()
+            self.animMargin.setLoopCount( 1 )
+            self.setMargin(8)
             self.setPix('On')
             QObject.connect(self.click, SIGNAL("timeout()"), self.center)
             self.state = True
+        else:
+            self.setPix('No')
+            self.emit(SIGNAL("gpsOn"))
+            self.animMargin.stop()
+            self.animMargin.setKeyValueAt(0, 8)
+            self.animMargin.setKeyValueAt(1, 16)
+            self.animMargin.setLoopCount( -1 )
+            self.animMargin.start()
 
 
 
@@ -438,12 +451,12 @@ class diagSearch(QWidget):
             result = []
             self.List.clear()
             for element in self.graph:
-                if str(self.Line.text().toLower()) in element.lower():
+                if str(self.Line.text().toLower()) in element.lower() and element[-1] != ']':
                     result += [element]
             if result == []:
-                QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
-            elif len(element) == 1 or str(self.Line.text()) in result:
-                self.emit(SIGNAL("selected(QString)"),self.Line.text())
+                QMaemo5InformationBox.information( self, self.tr("La recherche n\'a donn\xe9 aucun r\xe9sultat.") )
+            elif len(result) == 1 or str(self.Line.text()) in result:
+                self.emit(SIGNAL("selected(QString)"),result[0])
                 self.List.clear()
                 self.List.hide()
                 self.close()
@@ -482,186 +495,7 @@ class diagSearch(QWidget):
         QWidget.closeEvent (self, event)
 
 
-class diagLigne(QWidget):   
-    def __init__(self, already, portrait, parent=None):
-        super(diagLigne, self).__init__(parent)
-        self.fond = QGraphicsRectItem (parent.scene().sceneRect())
-        self.fond.setBrush(QBrush(QColor(0,0,0,153)))
-
-        self.hide()
-        QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
-
-        self.Layout = QVBoxLayout(self)
-
-        self.LayoutBouton = QHBoxLayout()
-        self.Metro = QPushButton("M",self)
-        self.Metro.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-        self.Metro.setMaximumSize(72,72)
-        self.Metro.setCheckable(True)
-
-
-        self.Metro.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlighted-text);color:palette(highlighted-text);border-radius: 35px;} QPushButton:checked {background-color: palette(highlight);}")
-        self.LayoutBouton.addWidget(self.Metro)
-        
-        self.Rer = QPushButton("R",self)
-        self.Rer.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-        self.Rer.setMaximumSize(72,72)
-        self.Rer.setCheckable(True)
-        self.Rer.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlighted-text);color:palette(highlighted-text);border-radius: 35px;} QPushButton:checked {background-color: palette(highlight);}")
-        self.LayoutBouton.addWidget(self.Rer)
-        
-        self.Tout = QPushButton("Tout",self)
-        self.Tout.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-        self.Tout.setMaximumSize(96,72)
-        self.Tout.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlight);color:palette(highlight);border-radius: 35px;} QPushButton:pressed {border-color:palette(link-visited);color:palette(link-visited)}")
-        self.LayoutBouton.addWidget(self.Tout)
-        
-        self.Aucun = QPushButton("Rien",self)
-        self.Aucun.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-        self.Aucun.setMaximumSize(96,72)
-        self.Aucun.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(link-visited);color:palette(link-visited);border-radius: 35px;} QPushButton:pressed {color:palette(highlight);border-color:palette(highlight);}")
-        self.LayoutBouton.addWidget(self.Aucun)
-        
-        self.Tout.clicked.connect(self.selectAll)
-        self.Aucun.clicked.connect(self.selectNone)
-        self.Metro.toggled.connect(self.selectMetro)
-        self.Rer.toggled.connect(self.selectRer)
-        
-        self.LayoutMetro = QGridLayout()
-        self.Layout.addLayout(self.LayoutMetro)
-        if portrait:
-            self.buildMetro(4)
-            self.setGeometry(10,44,460,600)
-        else:
-            self.buildMetro(8)
-            self.setGeometry(100,00,600,440)
-
-        self.LayoutRer = QHBoxLayout()
-        self.Layout.addLayout(self.LayoutRer)
-        i=0
-        lettre = ["A","B","C","D","E"]
-        for color in [station.RERA,station.RERB,station.RERC,station.RERD,station.RERE]:
-            boutton = QPushButton(lettre[i],self)
-            boutton.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-            boutton.setMaximumSize(64,64)
-            boutton.setCheckable(True)
-            boutton.setStyleSheet("QPushButton {border-radius: 32px;font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";} QPushButton:checked {background-color: "+color.name()+";color:white;}")
-            self.LayoutRer.addWidget(boutton)
-            i += 1
-
-        i = 0
-        self.LayoutTram = QHBoxLayout()
-        self.Layout.addLayout(self.LayoutTram)
-        lettre = ["T1","T2","T3","T4"]
-        for color in [station.LigneT1,station.LigneT2,station.LigneT3,station.LigneT4]:
-            boutton = QPushButton(lettre[i],self)
-            boutton.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-            boutton.setMaximumSize(64,64)
-            boutton.setCheckable(True)
-            boutton.setStyleSheet("QPushButton {border-radius: 32px;font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";} QPushButton:checked {background-color: "+color.name()+";color:white;}")
-            self.LayoutTram.addWidget(boutton)
-            i += 1
-        self.Layout.addLayout(self.LayoutBouton)
-
-        i=0
-        j=0
-        for idx in already:
-            if idx < 16:
-                self.LayoutMetro.itemAt(idx).widget().setChecked(True)
-                i += idx
-            elif idx < 21:
-                self.LayoutRer.itemAt(idx-16).widget().setChecked(True)
-                j+=idx
-            else:
-                self.LayoutTram.itemAt(idx-21).widget().setChecked(True)
-        if i == 120:
-            self.Metro.setChecked(True)
-        if j == 90:
-            self.Rer.setChecked(True)
-            
-#######Construction
-    def buildMetro(self,N):
-        i = 0       
-        for color in [station.Ligne1,station.Ligne2,station.Ligne3,station.Ligne4,station.Ligne5,station.Ligne6,station.Ligne7,station.Ligne8,station.Ligne9,station.Ligne10,station.Ligne11,station.Ligne12,station.Ligne13,station.Ligne14,station.Ligne3b,station.Ligne7b]:
-            button = QPushButton(str(i+1),self)
-            if i == 14:
-                button.setText('3b')
-            elif i == 15:
-                button.setText('7b')
-            button.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
-            button.setMaximumSize(64,64)
-            button.setCheckable(True)
-            button.setStyleSheet("QPushButton {font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";border-radius: 32px;} QPushButton:checked {background-color: "+color.name()+";color:white;}")
-            self.LayoutMetro.addWidget(button,i/N,i % N)
-            i += 1
-              
-    def selectMetro(self,b):
-        for j in range(16):
-            self.LayoutMetro.itemAt(j).widget().setChecked(b)
-
-    def selectRer(self,b):
-        for j in range(5):
-            self.LayoutRer.itemAt(j).widget().setChecked(b)
-
-
-    def selectAll(self):
-        self.Metro.setChecked(True)
-        self.Rer.setChecked(True)
-        for idx in range(25):
-            if idx < 16:
-                self.LayoutMetro.itemAt(idx).widget().setChecked(True)
-            elif idx < 21:
-                self.LayoutRer.itemAt(idx-16).widget().setChecked(True)
-            else:
-                self.LayoutTram.itemAt(idx-21).widget().setChecked(True)
-
-    def selectNone(self):
-        self.Metro.setChecked(False)
-        self.Rer.setChecked(False)
-        for idx in range(25):
-            if idx < 16:
-                self.LayoutMetro.itemAt(idx).widget().setChecked(False)
-            elif idx < 21:
-                self.LayoutRer.itemAt(idx-16).widget().setChecked(False)
-            else:
-                self.LayoutTram.itemAt(idx-21).widget().setChecked(False)
-   
-    def rotate(self):
-        if self.LayoutMetro.columnCount() == 8:
-            for idx in range(16):
-                self.LayoutMetro.itemAt(idx).widget().deleteLater()
-            self.buildMetro(4)
-            self.setGeometry(10,44,460,600)
-        else:
-            for idx in range(16):
-                self.LayoutMetro.itemAt(idx).widget().deleteLater()
-            self.buildMetro(8)
-            self.setGeometry(100,00,600,440)
-
-    def showEvent(self,event):
-        self.parent().scene().addItem(self.fond)
-        QWidget.showEvent (self, event)
-
-    def mousePressEvent(self,event):
-        self.close()
-        QWidget.mousePressEvent (self, event)
-
-    def closeEvent(self,event):
-        selec = []
-        for idx in range(25):
-            if idx < 16:
-                if self.LayoutMetro.itemAt(idx).widget().isChecked():
-                    selec.append(idx)
-            elif idx < 21:
-                if self.LayoutRer.itemAt(idx-16).widget().isChecked():
-                    selec.append(idx)
-            else:
-                if self.LayoutTram.itemAt(idx-21).widget().isChecked():
-                    selec.append(idx)
-        self.emit(SIGNAL("selection(PyQt_PyObject)"),selec)
-        QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
-        self.parent().scene().removeItem(self.fond)
-        QWidget.closeEvent (self, event)
+#diagLine dans le fichiers Station
 
         
 
@@ -680,12 +514,12 @@ class diagAbout(QWidget):
         self.Logo = QLabel(self)
         self.Logo.setPixmap(QPixmap("/home/user/Metro/Rtap_About.png"))
         self.Logo.setAlignment(Qt.AlignCenter)
-        self.Text = QLabel(''', les transports \xe0 Paris sur le N900 avec les doigts!
+        self.Text = QLabel(self.tr(""", les transports \xe0 Paris sur le N900 avec les doigts!
 
-0.9.7 (C) 2011 LGPL
+0.9.9 (C) 2011 LGPL
 Ahc\xe8ne 'Opax' Boubekki
 opax.gm@gmail.com
-Veuillez reporter les bugs \xe0 la m\xeame adresse, merci!''',self)
+Veuillez reporter les bugs \xe0 la m\xeame adresse, merci!"""),self)
         self.Text.setFont(QFont('Nokia Sans',18))
         self.Text.setWordWrap(True)
         
@@ -730,49 +564,49 @@ class diagAide(QWidget):
 
         self.Layout = QVBoxLayout(self)
         self.scroll = QScrollArea(self)
-        self.Titre = QLabel(' Aide ',self)
+        self.Titre = QLabel(self.tr(" Aide "),self)
         self.Titre.setFont(QFont('Nokia Sans',48))
         self.Titre.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed))
-        self.Text = QTextEdit('''<p align="center"><span style=" font-size:32pt; font-weight:600;">Carte</span></p>
-<p><b>S\xe9lection d'une station:</b></p>
-<p>Double-clique sur la station.</p>
-<p><br /><b>D\xe9placement:</b></p>
-<p>Clique et gliss\xe9.<br /></p>
-<p><b>Zoom: </b></p>
-<p>Double-clique et gliss\xe9 vers le bas/droite.
-<br /><br /><b>d\xe9Zoom: </b></p>
-<p>Double-clique et gliss\xe9 vers le haut/gauche.</p>
-<p></p>
-<p><br /><b>GPS:</b></p>
-<p><img src="/usr/share/icons/hicolor/32x32/hildon/camera_gps_location.png" width="32" height="32"/> : Double-clique pour activer la localisation.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png" width="32" height="32"/> : GPS activ\xe9. Double-clique pour d\xe9sactiver la localisation.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png" width="32" height="32"/> : Localisation pr\xe9cise. Double-clique pour d\xe9sactiver la localisation.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png" width="32" height="32"/> : GPS d\xe9sactiv\xe9 mais position enregistr\xe9e.</p>
-<p>Clique long (1s) pour centrer la carte la position GPS.</p>
-<p></p>
-<p><br /><b>Panneaux:</b></p>
-<p><img src="img_panneaux.png"/> : Clique pour cacher et d\xe9s\xe9lectionner la station.</p>
-<p></p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png" width="32" height="32"/> : Calculer l'itin\xe9raire.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing.png" width="32" height="32"/> : Calcul en cours.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/camera_playback.png" width="32" height="32"/> : Parcours de l'itin\xe9raire sur la carte</p>
-<p><br /></p>
-<p align="center"><span style=" font-size:32pt; font-weight:600;">Menu:</span></p>
-<p><br /><b>Recherche:</b></p>
-<p>S\xe9lection: Double clique.</p>
-<p>Sortir: Clique ailleurs.</p>
-<p></p>
-<p><br /><b>S\xe9lection des lignes:</b></p>
-<p>S\xe9lection/D\xe9s\xe9lection : Clique</p>
-<p>Les noms des stations sont affich\xe9 si maximum <b>quatre</b> lignes sont s\xe9lectionn\xe9es.</p>
-<p>Sortir/Valider: Clique ailleurs.</p>
-<p></p>
-<p><br /><b>Aide:</b></p>
-<p>Sortir: Clique ailleurs.</p>
-<p></p>
-<p><br /><b>\xc0 Propos:</b></p>
-<p>Sortir: Clique ailleurs.</p>
-<p><br /></p>''',self.scroll)
+        self.Text = QTextEdit("<p align='center'><span style=' font-size:32pt; font-weight:600;'>"+self.tr("Carte")+"</span></p> \
+<p><b>"+self.tr("S\xe9lection d'une station:")+"</b></p> \
+<p>"+self.tr("Double-clique sur la station.")+"</p> \
+<p><br /><b>"+self.tr("D\xe9placement:")+"</b></p> \
+<p>"+self.tr("Clique et gliss\xe9.")+"<br /></p> \
+<p><b>"+self.tr("Zoom: ")+"</b></p> \
+<p>"+self.tr("Double-clique et gliss\xe9 vers le bas/droite.")+" \
+<br /><br /><b>"+self.tr("d\xe9Zoom: ")+"</b></p> \
+<p>"+self.tr("Double-clique et gliss\xe9 vers le haut/gauche.")+"</p> \
+<p></p> \
+<p><br /><b>GPS:</b></p> \
+<p><img src='/usr/share/icons/hicolor/32x32/hildon/camera_gps_location.png' width='32' height='32'/> : "+self.tr("Double-clique pour activer la localisation.")+"</p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png' width='32' height='32'/> : "+self.tr("GPS activ\xe9. Double-clique pour d\xe9sactiver la localisation.")+"</p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png' width='32' height='32'/> : "+self.tr("Localisation précise. Double-clique pour désactiver la localisation.")+"</p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png' width='32' height='32'/> : "+self.tr("GPS désactivé mais position enregistrée.")+"</p> \
+<p>"+self.tr("Clique long (1s) pour centrer la carte la position GPS.")+"</p> \
+<p></p> \
+<p><br /><b>"+self.tr("Panneaux:")+"</b></p> \
+<p><img src='img_panneaux.png'/> : "+self.tr("Clique pour cacher et d\xe9s\xe9lectionner la station.")+"</p> \
+<p></p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png' width='32' height='32'/> : "+self.tr("Calculer l'itin\xe9raire.")+"</p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing.png' width='32' height='32'/> : "+self.tr("Calcul en cours.")+"</p> \
+<p><img src='/usr/share/icons/hicolor/48x48/hildon/camera_playback.png' width='32' height='32'/> : "+self.tr("Parcours de l'itin\xe9raire sur la carte.")+"</p> \
+<p><br /></p> \
+<p align='center'><span style=' font-size:32pt; font-weight:600;'>"+self.tr("Menu:")+"</span></p> \
+<p><br /><b>"+self.tr("Recherche:")+"</b></p> \
+<p>"+self.tr("S\xe9lection: Double clique.")+"</p> \
+<p>"+self.tr("Sortir: Clique ailleurs.")+"</p> \
+<p></p> \
+<p><br /><b>"+self.tr("S\xe9lection des lignes:")+"</b></p> \
+<p>"+self.tr("S\xe9lection/D\xe9s\xe9lection : Clique")+"</p> \
+<p>"+self.tr("Les noms des stations sont affichés si maximum <b>quatre</b> lignes sont sélectionnées.")+"</p> \
+<p>"+self.tr("Sortir/Valider: Clique ailleurs.")+"</p> \
+<p></p> \
+<p><br /><b>"+self.tr("Aide:")+"</b></p> \
+<p>"+self.tr("Sortir: Clique ailleurs.")+"</p> \
+<p></p> \
+<p><br /><b>"+self.tr("\xc0 Propos:")+"</b></p> \
+<p>"+self.tr("Sortir: Clique ailleurs.")+"</p> \
+<p><br /></p>",self.scroll)
         self.Text.setFont(QFont('Nokia Sans',18))
         self.Text.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
         self.Text.setReadOnly ( True )
@@ -792,6 +626,10 @@ class diagAide(QWidget):
             self.setGeometry(100,60,600,340)
             self.Text.resize(self.width()-40,2000)
 
+    def mousePressEvent(self,event):
+        self.close()
+        QWidget.mousePressEvent (self, event)
+
             
     def showEvent(self,event):
         self.parent().scene().addItem(self.fond)
